"""Utilities for loading various files."""
from typing import Any

import yaml


def yaml_from_file(filepath: str) -> Any:
    """Return a loaded YAML file."""
    with open(filepath) as content:
        return yaml.load(content, Loader=yaml.FullLoader)



"""Utilities for configuring ansible runtime environment."""
import hashlib
import os


def get_cache_dir(project_dir: str) -> str:
    """Compute cache directory to be used based on project path."""
    # 6 chars of entropy should be enough
    cache_key = hashlib.sha256(os.path.abspath(project_dir).encode()).hexdigest()[:6]
    cache_dir = "%s/ansible-compat/%s" % (
        os.getenv("XDG_CACHE_HOME", os.path.expanduser("~/.cache")),
        cache_key,
    )
    return cache_dir



#! /usr/bin/env python3
"""Ansible-lint distribution package setuptools installer.

The presence of this file ensures the support
of pip editable mode *with setuptools only*.
"""
import setuptools

# https://github.com/jazzband/pip-tools/issues/1278
setuptools.setup(
    use_scm_version={"local_scheme": "no-local-version"},
    setup_requires=["setuptools_scm[toml]>=3.5.0"],
)
